@@ -3,9 +3,9 @@ package Fey::ORM;
 use strict;
 use warnings;
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
-use Moose 0.71_01 ();
+use Moose 0.74 ();
 
 
 1;
